@@ -17,10 +17,12 @@ package CGI::Cookie;
 #   http://www.genome.wi.mit.edu/ftp/pub/software/WWW/cgi_docs.html
 #   ftp://ftp-genome.wi.mit.edu/pub/software/WWW/
 
-$CGI::Cookie::VERSION='1.05';
+$CGI::Cookie::VERSION='1.06';
 
 use CGI;
-use overload '""' => \&as_string;
+use overload '""' => \&as_string,
+    'cmp' => \&compare,
+    'fallback'=>1;
 
 # fetch a list of cookies from the environment and
 # return as a hash.  the cookies are parsed as normal
@@ -67,7 +69,9 @@ sub parse {
 	my($key,$value) = split("=");
 	my(@values) = map CGI::unescape($_),split('&',$value);
 	$key = CGI::unescape($key);
-	$results{$key} = $self->new(-name=>$key,-value=>\@values);
+	# A bug in Netscape can cause several cookies with same name to
+	# appear.  The FIRST one in HTTP_COOKIE is the most recent version.
+	$results{$key} ||= $self->new(-name=>$key,-value=>\@values);
     }
     return \%results unless wantarray;
     return %results;
@@ -122,6 +126,12 @@ sub as_string {
     return join("; ",$cookie,@constant_values);
 }
 
+sub compare {
+    my $self = shift;
+    my $value = shift;
+    return "$self" cmp $value;
+}
+
 # accessors
 sub name {
     my $self = shift;
